[前][次][番号順一覧][スレッド一覧]

ruby-changes:54377

From: k0kubun <ko1@a...>
Date: Fri, 28 Dec 2018 01:24:51 +0900 (JST)
Subject: [ruby-changes:54377] k0kubun:r66591 (trunk): test/mkmf/test_flags.rb: try to suppress random CI failure

k0kubun	2018-12-28 01:24:46 +0900 (Fri, 28 Dec 2018)

  New Revision: 66591

  https://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=revision&revision=66591

  Log:
    test/mkmf/test_flags.rb: try to suppress random CI failure
    
    on AIX ppc
    https://rubyci.org/logs/rubyci.s3.amazonaws.com/aix71_ppc/ruby-trunk/log/20181226T113305Z.fail.html.gz
    
    test/lib/test/unit/assertions.rb: ditto, for TestIO#test_copy_stream_no_busy_wait

  Modified files:
    trunk/test/lib/test/unit/assertions.rb
    trunk/test/mkmf/test_flags.rb
Index: test/mkmf/test_flags.rb
===================================================================
--- test/mkmf/test_flags.rb	(revision 66590)
+++ test/mkmf/test_flags.rb	(revision 66591)
@@ -41,7 +41,7 @@ class TestMkmf https://github.com/ruby/ruby/blob/trunk/test/mkmf/test_flags.rb#L41
     end
 
     def test_try_cflag_invalid_opt
-      assert_separately([], <<-'end;') #do
+      assert_separately([], <<-'end;', timeout: 30) #do
         assert(!try_cflags("nosuch.c"), TestMkmf::MKMFLOG)
         assert(have_devel?, TestMkmf::MKMFLOG)
       end;

Index: test/lib/test/unit/assertions.rb
===================================================================
--- test/lib/test/unit/assertions.rb	(revision 66590)
+++ test/lib/test/unit/assertions.rb	(revision 66591)
@@ -761,7 +761,7 @@ eom https://github.com/ruby/ruby/blob/trunk/test/lib/test/unit/assertions.rb#L761
         # [ruby-core:81540]
         min_hz = windows? ? 67 : 100
         min_measurable = 1.0 / min_hz
-        min_measurable *= 1.10 # add a little (10%) to account for misc. overheads
+        min_measurable *= 1.30 # add a little (30%) to account for misc. overheads
         if max < min_measurable
           max = min_measurable
         end
--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]